﻿using System;
using System.Windows;
using System.Linq;

namespace EventComposition
{
	public partial class ChoiceControl
    {
        #region Public Properties

        /// <summary>
        /// Observable of the current selections.
        /// </summary>
        public IObservable<int> OptionSelections { get; private set; }

        #endregion

        #region Dependency Properties

        public string Heading
        {
            get { return (string)GetValue(HeadingProperty); }
            set { SetValue(HeadingProperty, value); }
        }

        public static readonly DependencyProperty HeadingProperty =
            DependencyProperty.Register("Heading", typeof(string), typeof(ChoiceControl), new PropertyMetadata(String.Empty));

        #endregion

        #region Public Methods

        public ChoiceControl()
        {
            InitializeComponent();

            // just map the selections to an integer and return the result stream as IObservable<int>
            OptionSelections = Observable.Merge(
                Observable.FromEvent<RoutedEventArgs>(optionButton1, "Checked").Select(_ => 1),
                Observable.FromEvent<RoutedEventArgs>(optionButton2, "Checked").Select(_ => 2),
                Observable.FromEvent<RoutedEventArgs>(optionButton3, "Checked").Select(_ => 3)
            );
        }

	    public void ClearAll()
	    {
	        optionButton1.IsChecked = false;
            optionButton2.IsChecked = false;
            optionButton3.IsChecked = false;
        }

        #endregion
    }
}